<div align="center">

# aiorussound

#### An async python package for interfacing with Russound RIO hardware

[![](https://github.com/noahhusby/aiorussound/actions/workflows/publish.yml/badge.svg)](https://github.com/noahhusby/aiorussound/actions/workflows/build.yml)
[![](https://img.shields.io/github/license/noahhusby/aiorussound)](https://github.com/noahhusby/aiorussound/blob/main/LICENSE)
[![](https://img.shields.io/pypi/implementation/aiorussound
)](https://pypi.org/project/aiorussound/)
[![](https://img.shields.io/pypi/v/aiorussound
)](https://pypi.org/project/aiorussound/)
[![](https://img.shields.io/pypi/dm/aiorussound
)](https://pypi.org/project/aiorussound/)

</div>

This module implements a Python client for the Russound I/O (RIO) protocol used to control Russound audio controllers. RIO supports a superset of the RNET feature set, allows for push notifications of system changes and supports TCP/IP and RS232 communication.

## Acknowledgements
This is the continuation of the `russound_rio` package. This wouldn't be possible without the excellent work from [@wickerwaka](https://github.com/wickerwaka) and [@chphilli](https://github.com/chphilli).

